==> imageTagger.0.1.tgz: imageTagger/translations/imageTagger_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en">
<context>
    <name>Bildauswahl</name>
    <message>
        <location filename="../forms/bildauswahl.ui" line="13"/>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../forms/bildauswahl.ui" line="25"/>
        <source>«</source>
        <translation type="obsolete">«</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="22"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="24"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../forms/bildauswahl.ui" line="46"/>
        <source>»</source>
        <translation type="obsolete">»</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="14"/>
        <source>Bildauswahl</source>
        <translation>Picture selector</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="21"/>
        <source>&#xab;</source>
        <translation type="obsolete">«</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="25"/>
        <source>&#xbb;</source>
        <translation type="obsolete">»</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="21"/>
        <source>&lt;&lt;</source>
        <translation>«</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="25"/>
        <source>&gt;&gt;</source>
        <translation>»</translation>
    </message>
</context>
<context>
    <name>MainWin</name>
    <message>
        <location filename="../src/mainwin.cpp" line="74"/>
        <source>Tags wurden ge&#xe4;ndert</source>
        <translation>Tags have been modified</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="75"/>
        <source>Speichern?</source>
        <translation>Save?</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="63"/>
        <source>Bild &#xf6;ffnen</source>
        <translation>Open picture</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="54"/>
        <source>Images (*.png *.jpg *.jpeg *.xpm *.gif)</source>
        <translation type="obsolete">Images (*.png *.jpg *.jpeg *.xpm *.gif)</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="94"/>
        <source>Fehler</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="95"/>
        <source>Bild %1 konnte nicht geladen werden</source>
        <translation>Could not open file %1</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="64"/>
        <source>Images (*.png *.jpg *.jpeg *.JPG *.xpm *.gif)</source>
        <translation>Images (*.png *.jpg *.jpeg *.JPG *.xpm *.gif)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../forms/mainwin.ui" line="19"/>
        <source>MainWindow</source>
        <translation>imageTagger</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="48"/>
        <source>Neuer Tag</source>
        <translation>New tag</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="128"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="135"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="169"/>
        <source>Datei</source>
        <translation>File</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../forms/mainwin.ui" line="181"/>
        <source>Bilder öffnen</source>
        <translation>Open pictures</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="186"/>
        <source>Speichern</source>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="191"/>
        <source>Beenden</source>
        <translation>Quit</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="196"/>
        <source>Bilder suchen</source>
        <translation>Search pictures</translation>
    </message>
</context>
<context>
    <name>Tagsuche</name>
    <message>
        <location filename="../forms/tagsuche.ui" line="27"/>
        <source>Dialog</source>
        <translation>Search tags</translation>
    </message>
    <message>
        <location filename="../forms/tagsuche.ui" line="47"/>
        <source>Bilder mit folgendem Tag suchen:</source>
        <translation>Serch pictures with tag:</translation>
    </message>
</context>
</TS>

==> imageTagger.0.3.tgz: imageTagger/translations/imageTagger_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en">
<context>
    <name>Bildauswahl</name>
    <message>
        <location filename="../forms/bildauswahl.ui" line="13"/>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../forms/bildauswahl.ui" line="25"/>
        <source>«</source>
        <translation type="obsolete">«</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="40"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="42"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../forms/bildauswahl.ui" line="46"/>
        <source>»</source>
        <translation type="obsolete">»</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="32"/>
        <source>Bildauswahl</source>
        <translation>Picture selector</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="21"/>
        <source>&#xab;</source>
        <translation type="obsolete">«</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="25"/>
        <source>&#xbb;</source>
        <translation type="obsolete">»</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="39"/>
        <source>&lt;&lt;</source>
        <translation>«</translation>
    </message>
    <message>
        <location filename="../src/bildauswahl.cpp" line="43"/>
        <source>&gt;&gt;</source>
        <translation>»</translation>
    </message>
</context>
<context>
    <name>MainWin</name>
    <message>
        <location filename="../src/mainwin.cpp" line="74"/>
        <source>Tags wurden ge&#xe4;ndert</source>
        <translation type="obsolete">Tags have been modified</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="103"/>
        <source>Speichern?</source>
        <translation>Save?</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="63"/>
        <source>Bild &#xf6;ffnen</source>
        <translation type="obsolete">Open picture</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="54"/>
        <source>Images (*.png *.jpg *.jpeg *.xpm *.gif)</source>
        <translation type="obsolete">Images (*.png *.jpg *.jpeg *.xpm *.gif)</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="122"/>
        <source>Fehler</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="123"/>
        <source>Bild %1 konnte nicht geladen werden</source>
        <translation>Could not open file %1</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="91"/>
        <source>Images (*.png *.jpg *.jpeg *.JPG *.xpm *.gif)</source>
        <translation>Images (*.png *.jpg *.jpeg *.JPG *.xpm *.gif)</translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="90"/>
        <source>Bild oeffnen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwin.cpp" line="102"/>
        <source>Tags wurden geaendert</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../forms/mainwin.ui" line="19"/>
        <source>MainWindow</source>
        <translation>imageTagger</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="48"/>
        <source>Neuer Tag</source>
        <translation>New tag</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="128"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="135"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="169"/>
        <source>Datei</source>
        <translation>File</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../forms/mainwin.ui" line="188"/>
        <source>Bilder öffnen</source>
        <translation>Open pictures</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="193"/>
        <source>Speichern</source>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="198"/>
        <source>Beenden</source>
        <translation>Quit</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="203"/>
        <source>Bilder suchen</source>
        <translation>Search pictures</translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="178"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/mainwin.ui" line="208"/>
        <source>Optionen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Optionen</name>
    <message>
        <location filename="../forms/optionen.ui" line="13"/>
        <source>Dialog</source>
        <translation type="unfinished">Search tags</translation>
    </message>
    <message>
        <location filename="../forms/optionen.ui" line="28"/>
        <source>Datenbankpfad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/optionen.ui" line="35"/>
        <source>Suchen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/optionen.cpp" line="50"/>
        <source>datenbankpfad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tagsuche</name>
    <message>
        <location filename="../forms/tagsuche.ui" line="27"/>
        <source>Dialog</source>
        <translation>Search tags</translation>
    </message>
    <message>
        <location filename="../forms/tagsuche.ui" line="47"/>
        <source>Bilder mit folgendem Tag suchen:</source>
        <translation>Serch pictures with tag:</translation>
    </message>
</context>
</TS>
